@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: MissingH
-version: 1.1.1.0
-id: MissingH-1.1.1.0-78e817b067e5797c042b7643c22839b6
+version: 1.2.0.0
+id: MissingH-1.2.0.0-802d843c83575108fd1ecf601b23d5ed
 
 license: BSD3
 copyright: Copyright (c) 2004-2011 John Goerzen
@@ -35,34 +35,35 @@ exposed-modules: Data.String.Utils System.IO.Utils System.IO.Binary
                  Data.MIME.Types System.Console.GetOpt.Utils
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/MissingH-1.1.1.0
-library-dirs: /usr/local/lib/ghc/MissingH-1.1.1.0
-hs-libraries: HSMissingH-1.1.1.0
+import-dirs: /usr/local/lib/ghc/MissingH-1.2.0.0
+library-dirs: /usr/local/lib/ghc/MissingH-1.2.0.0
+hs-libraries: HSMissingH-1.2.0.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: HUnit-1.2.5.1-3a320959e06d702551395cbe60e9b4d5
-         array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
-         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
-         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
-         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
-         hslogger-1.1.5-718f4741935ee5391186790abc975888
-         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
-         network-2.3.1.0-abef231ef624b7502aa8b0353f2d5ca3
-         old-locale-1.0.0.4-5e45cabd3b4fdcad9e353ea3845f5ef7
-         old-time-1.1.0.0-c11d19d5710541e7a9ae41c1582972eb
-         parsec-3.1.3-07e54fceec3486ec01b4c366cf3d07fd
-         process-1.1.0.1-608c248c1528f46eb960a08cead77291
-         random-1.0.1.1-d8f82f84701874725b418c29860a58e0
-         regex-compat-0.95.1-7e067d726f01aa046c9d3207860a884e
-         unix-2.5.1.1-0adea5be633a6b5a124519287d54626d
+depends: HUnit-1.2.5.2-6e02ecc15e3cc5ab8ef10df50d05a1a9
+         array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
+         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
+         directory-1.2.0.1-ee04c884b72040489d2e2ca6dd62e6ac
+         filepath-1.3.0.1-b12cbe18566fe1532a1fda4c85e31cbe
+         hslogger-1.2.1-4c18aebfb9eaa2568b8e99aa6298aede
+         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
+         network-2.4.1.2-2410fd33cfc22dd877d4b24516181434
+         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
+         old-time-1.1.0.1-029c40e673a46f6084b935f654a6fa28
+         parsec-3.1.3-8bc25b86282839a5b5fcb3c428bb3b9c
+         process-1.1.0.2-76e05340eb66705981411022731ca84a
+         random-1.0.1.1-023a342365721422ffd5a919bc8708bb
+         regex-compat-0.95.1-5aa32e2bfd54140cd88d19d49933a997
+         time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
+         unix-2.6.0.1-2939d4be83b53d31ca104e0487b1ef98
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-MissingH-1.1.1.0/html/MissingH.haddock
-haddock-html: /usr/local/share/doc/hs-MissingH-1.1.1.0/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-MissingH-1.2.0.0/html/MissingH.haddock
+haddock-html: /usr/local/share/doc/hs-MissingH-1.2.0.0/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
